<?php
/**
 * Plugin Name:       Adcell Product Feed
 * Plugin URI:        https://c-om-petence.de/adcell-feed/
 * Description:       Supply Product Feed from Woocommerce for Adcell
 * Version:           1.11
 * Author:            Bastian Schneider
 * Author URI:        https://c-om-petence.de/
 */
add_action('admin_menu', 'compadcf_add_admin_menu');
add_action('admin_init', 'compadcf_settings_init');

function compadcf_add_admin_menu() {
    add_menu_page('Adcell Feed', 'Adcell Feed', 'manage_options', 'adcell_feed', 'compadcf_options_page');
}

function compadcf_settings_init() {

    register_setting('pluginPage', 'compadcf_settings');

    add_settings_section(
            'compadcf_pluginPage_section',
            __('Einstellungen Adcell Feed', 'compadcf'),
            'compadcf_settings_section_callback',
            'pluginPage'
    );

    add_settings_field(
            'compadcf_hersteller',
            __('Hersteller', 'compadcf'),
            'compadcf_text_field_0_render',
            'pluginPage',
            'compadcf_pluginPage_section'
    );

    add_settings_field(
            'compadcf_shipping',
            __('Versandkosten', 'compadcf'),
            'compadcf_text_field_1_render',
            'pluginPage',
            'compadcf_pluginPage_section'
    );

    add_settings_field(
            'compadcf_delivery',
            __('Lieferzeit', 'compadcf'),
            'compadcf_text_field_2_render',
            'pluginPage',
            'compadcf_pluginPage_section'
    );
}

function compadcf_text_field_0_render() {

    $options = get_option('compadcf_settings');
    ?>
    <input type='text' name='compadcf_settings[compadcf_hersteller]' value='<?php echo $options['compadcf_hersteller']; ?>'>
    <?php
}

function compadcf_text_field_1_render() {

    $options = get_option('compadcf_settings');
    ?>
    <input type='text' name='compadcf_settings[compadcf_shipping]' value='<?php echo $options['compadcf_shipping']; ?>'>
    <?php
}

function compadcf_text_field_2_render() {

    $options = get_option('compadcf_settings');
    ?>
    <input type='text' name='compadcf_settings[compadcf_delivery]' value='<?php echo $options['compadcf_delivery']; ?>'>
    <?php
}

function compadcf_settings_section_callback() {
    
}

function compadcf_options_page() {
    ?>
    <form action='options.php' method='post'>

        <h2>Adcell Feed</h2>

        <?php
        settings_fields('pluginPage');
        do_settings_sections('pluginPage');
        submit_button();
        ?>

    </form>
    <br/><br/>Feed URL: <br/>
    <?php
    echo home_url() . '/export_adcell_feed.csv';
}

add_action('init', 'compadcf_url_handler');

function compadcf_url_handler() {
    if (substr($_SERVER["REQUEST_URI"], -22) == 'export_adcell_feed.csv') {
        $options = get_option('compadcf_settings');
        $hersteller = $options['compadcf_hersteller'];
        $shipping = $options['compadcf_shipping'];
        $delivery = $options['compadcf_delivery'];
        $plugin_path = trailingslashit(WP_PLUGIN_DIR) . 'woocommerce/woocommerce.php';
        if (
                in_array($plugin_path, wp_get_active_and_valid_plugins()) || in_array($plugin_path, wp_get_active_network_plugins())
        ) {
            header("HTTP/1.1 200");
            header('Content-type: text/csv');
            header('Content-Disposition: attachment; filename="Feed.csv"');

            $args = array('status' => 'publish', 'limit' => -1);
            $products = wc_get_products($args);
            echo '"url","title","description","price","old_price","Waehrung","EAN","ID","Hersteller","image","Kategorie","Versandkosten","Lieferzeit",'
            . '"Lagerstand","Gewicht","Grundpreis","Grundpreiseinheit","Inhalt"' . "\r\n";
            foreach ($products as $product) {
                $metadata = get_post_meta($product->id);
                echo '"' . get_post_permalink($product->id) . '",';
                echo '"' . $product->name . '",';
                echo '"' . str_replace(["\n", "\r"], '', nl2br(strip_tags(preg_replace('/<style(.*)<\/style>/s', '', $product->description)))) . '",';
                echo '"' . number_format($product->price, 2) . '",';
                if ($product->regular_price > $product->price) {
                    echo '"' . number_format($product->regular_price, 2) . '",';
                } else {
                    echo '"",';
                }
                echo '"EUR",';
                echo '"' . $metadata['_ts_gtin'][0] . '",';
                echo '"' . $product->id . '",';
                echo '"' . $hersteller . '",';
                echo '"' . wp_get_attachment_image_src(get_post_thumbnail_id($product->id), 'single-post-thumbnail')[0] . '",';
                echo '"' . strip_tags(wc_get_product_category_list($product->id)) . '",';
                echo '"' . $shipping . '",';
                echo '"' . $delivery . '",';
                echo '"' . $product->stock_quantity . '",';
                echo '"' . $product->weight . '",';
                echo '"' . number_format($metadata['_unit_price'][0], 2) . '",';
                echo '"' . $metadata['_unit_base'][0] . $metadata['_unit'][0] . '",';
                echo '"' . $metadata['_unit_product'][0] . $metadata['_unit'][0] . '"' . "\r\n";
            }
            exit;
        }
    }
}
